Module zone_alloc::strong_registry
source · Structs
- The same as
Registry<T>, but with strongly-typed handles to prevent handles from being shared across multiple registries.
Traits
- A strong handle to data registered in a specific
StrongRegistry.